@@ -1,22 +1,11 @@
-/***************************************************************************
-                          ResultWidget.h  -  paint the result
-                             -------------------
-    begin                : 2004/05/30
-    copyright            : (C) 2004 by Sebastian Stein
-    email                : seb.kde@hpfsc.de
+/*
+    RatioWidget.h  -  paint a ratio
+    SPDX-FileCopyrightText: 2004 Sebastian Stein <seb.kde@hpfsc.de>
+    SPDX-FileCopyrightText: 2008 Tadeu Araujo <tadeu.araujo@ltia.fc.unesp.br>
+    SPDX-FileCopyrightText: 2008 Danilo Balzaque <danilo.balzaque@ltia.fc.unesp.br>
 
-    copyright            : (C) 2008 by Tadeu Araujo, tadeu.araujo@ltia.fc.unesp.br
-    copyright            : (C) 2008 by Danilo Balzaque, danilo.balzaque@ltia.fc.unesp.br
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef RESULTWIDGET_H
 #define RESULTWIDGET_H
@@ -46,7 +35,7 @@ public:
     explicit ResultWidget(QWidget * parent = nullptr);
 
     /** destructor */
-    ~ResultWidget();
+    ~ResultWidget() override;
 
     /** set the task to be displayed */
     void setResult(const Ratio &para_result, int k);
@@ -80,7 +69,7 @@ private:
     Ratio m_result;
 
     /** overriding the paint event of FractionBaseWidget */
-    void paintEvent(QPaintEvent*) Q_DECL_OVERRIDE;
+    void paintEvent(QPaintEvent*) override;
 
     void Init();
     void showResult()   ;
